@@ -93,7 +93,8 @@ sub new {
   @location = $geocoder->geocode(location => $location);
 
 Queries I<$location> to Google Places geocoding API and returns hash
-reference returned back from API server. When you cann the method in
+reference returned back from API server.
+When you call the method in
 an array context, it returns all the candidates got back, while it
 returns the 1st one in a scalar context.
 
@@ -113,7 +114,7 @@ sub geocode {
     }
 
     my $location = $param{location}
-        or Carp::croak("Usage: geocode(location => \$location)");
+        or Carp::croak('Usage: geocode(location => $location)');
 
     if (Encode::is_utf8($location)) {
         $location = Encode::encode_utf8($location);
@@ -148,11 +149,11 @@ sub geocode {
     my $res = $self->{ua}->get($url);
 
     if ($res->is_error) {
-        Carp::croak("Google Places API returned error: " . $res->status_line);
+        Carp::croak('Google Places API returned error: ', $res->status_line());
     }
 
-    my $json = JSON->new->utf8;
-    my $data = $json->decode($res->content);
+    my $json = JSON->new()->utf8();
+    my $data = $json->decode($res->decoded_content());
 
     unless ($data->{status} eq 'OK' || $data->{status} eq 'ZERO_RESULTS') {
         Carp::croak(sprintf "Google Places API returned status '%s'", $data->{status});
@@ -182,7 +183,7 @@ sub reverse_geocode {
     }
 
     my $latlng = $param{latlng}
-        or Carp::croak("Usage: reverse_geocode(latlng => \$latlng)");
+        or Carp::croak('Usage: reverse_geocode(latlng => $latlng)');
 
     return $self->geocode(location => $latlng, reverse => 1);
 }
@@ -292,6 +293,10 @@ Based on L<Geo::Coder::Google> by Tatsuhiko Miyagawa C<< <miyagawa@bulknews.net>
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
+=head1 BUGS
+
+I believe that reverse may longer work.
+
 =head1 SEE ALSO
 
 L<Geo::Coder::Yahoo>
